@@ -899,9 +899,9 @@ MATRIX *mat;
 if (mat == (MATRIX *) NULL ) return;
 mat->nrows = 0;
 mat->ncols = 0;
-if (mat->data != (double *)NULL ) free((char *) mat->data );
+/*if (mat->data != (double *)NULL ) free((char *) mat->data );*/
 mat->data = (double *)NULL;
-if (mat != (MATRIX *)NULL) free((char *) mat );
+/*if (mat != (MATRIX *)NULL) free((char *) mat );*/
 mat = (MATRIX *)NULL;
 }
 
@@ -1476,28 +1476,23 @@ nel = mat->nrows * mat->ncols;
 
 for ( curel = mat->data ;  curel < mat->data + nel ; curel++ )
 	{
-	printf(  ((fabs(*curel)<.00001) && (fabs(*curel)>0.)) ? "%.4le%c" : "%.4lf%c" , *curel, 
+	printf(  ((fabs(*curel)<.00001) && (fabs(*curel)>0.)) ? "%.4e%c" : "%.4f%c" , *curel, 
 			( outtok++%mat->ncols == mat->ncols-1 )
 			? '\n' : ' ' );
 	}
 /* DOES NOT CLEAN */
 }
-
-
-
- 
  
 static MATRIX *VC_GEE_luinv(X)
 MATRIX *X;
 {
   MATRIX *Y;
-  doublereal det[2] , *work;
-  integer job[1];
-  static int VC_GEE_dgefaXXY_(), VC_GEE_dgediXXY_();
+  double det[2] , *work;
+  int job[1];
 
-  doublereal *y;
-  integer info[1], *ipvt;
-  integer nrows, ncols;
+  double *y;
+  int info[1], *ipvt;
+  int nrows, ncols;
 
   det[0] = 0.;
   det[1] = 0.;
@@ -1510,17 +1505,17 @@ MATRIX *X;
   nrows = X->nrows;
   ncols = X->ncols;
 
-  ipvt = (integer *)malloc((unsigned)nrows*sizeof(integer));
-  work = (doublereal *)malloc((unsigned)nrows*sizeof(doublereal));
+  ipvt = (int *)malloc((unsigned)nrows*sizeof(int));
+  work = (double *)malloc((unsigned)nrows*sizeof(double));
 
-  y = (doublereal *)Y->data;
-  VC_GEE_dgefaXXY_(y,&nrows,&ncols,ipvt,info);
+  y = (double *)Y->data;
+  F77_NAME(dgefa)(y,&nrows,&ncols,ipvt,info);
 
   job[0] = 11;
-  VC_GEE_dgediXXY_(y,&nrows,&ncols,ipvt,det,work,job);
+  F77_NAME(dgedi)(y,&nrows,&ncols,ipvt,det,work,job);
 
-  free(ipvt);
-  free(work);
+  /*free(ipvt);
+    free(work);*/
   free_if_ephemeral(X);
 
   return Y;
@@ -1648,698 +1643,6 @@ static  MATRIX *VC_GEE_matanticlog( x )
  }
 
 
-/* gee support @(#) clinluxxy.c 3.1 94/03/03 */
-
-
-
-static /* Subroutine */ int VC_GEE_daxpyXXY_(n, da, dx, incx, dy, incy)
-integer *n;
-doublereal *da, *dx;
-integer *incx;
-doublereal *dy;
-integer *incy;
-{
-    /* System generated locals */
-    integer i__1;
-
-    /* Local variables */
-    static integer i, m, ix, iy, mp1;
-
-
-/*     constant times a VC_GEE_vector plus a VC_GEE_vector. */
-/*     uses unrolled loops for increments equal to one. */
-/*     jack dongarra, linpack, 3/11/78. */
-
-
-    /* Parameter adjustments */
-    --dy;
-    --dx;
-
-    /* Function Body */
-    if (*n <= 0) {
-	return 0;
-    }
-    if (*da == 0.) {
-	return 0;
-    }
-    if (*incx == 1 && *incy == 1) {
-	goto L20;
-    }
-
-/*        code for unequal increments or equal increments */
-/*          not equal to 1 */
-
-    ix = 1;
-    iy = 1;
-    if (*incx < 0) {
-	ix = (-(*n) + 1) * *incx + 1;
-    }
-    if (*incy < 0) {
-	iy = (-(*n) + 1) * *incy + 1;
-    }
-    i__1 = *n;
-    for (i = 1; i <= i__1; ++i) {
-	dy[iy] += *da * dx[ix];
-	ix += *incx;
-	iy += *incy;
-/* L10: */
-    }
-    return 0;
-
-/*        code for both increments equal to 1 */
-
-
-/*        clean-up loop */
-
-L20:
-    m = *n % 4;
-    if (m == 0) {
-	goto L40;
-    }
-    i__1 = m;
-    for (i = 1; i <= i__1; ++i) {
-	dy[i] += *da * dx[i];
-/* L30: */
-    }
-    if (*n < 4) {
-	return 0;
-    }
-L40:
-    mp1 = m + 1;
-    i__1 = *n;
-    for (i = mp1; i <= i__1; i += 4) {
-	dy[i] += *da * dx[i];
-	dy[i + 1] += *da * dx[i + 1];
-	dy[i + 2] += *da * dx[i + 2];
-	dy[i + 3] += *da * dx[i + 3];
-/* L50: */
-    }
-    return 0;
-} /* daxpy_ */
-
-
-/* dgeco.f -- translated by f2c (version of 21 October 1993  13:46:10).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
-*/
-
-
-/* Table of constant values */
-
-static integer c__1 = 1;
-
-
-/* dgedi.f -- translated by f2c (version of 21 October 1993  13:46:10).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
-*/
-
-
-/* Table of constant values */
-
-
-static /* Subroutine */ int VC_GEE_dgediXXY_(a, lda, n, ipvt, det, work, job)
-doublereal *a;
-integer *lda, *n, *ipvt;
-doublereal *det, *work;
-integer *job;
-{
-    /* System generated locals */
-    integer a_dim1, a_offset, i__1, i__2;
-
-    /* Local variables */
-    static integer i, j, k, l;
-    static doublereal t;
-    static /* Subroutine */ int VC_GEE_dscalXXY_(), VC_GEE_dswapXXY_(), VC_GEE_daxpyXXY_();
-    static integer kb, kp1, nm1;
-    static doublereal ten;
-
-
-/*     dgedi computes the determinant and inverse of a matrix */
-/*     using the factors computed by dgeco or dgefa. */
-
-/*     on entry */
-
-/*        a       double precision(lda, n) */
-/*                the output from dgeco or dgefa. */
-
-/*        lda     integer */
-/*                the leading dimension of the array  a . */
-
-/*        n       integer */
-/*                the order of the matrix  a . */
-
-/*        ipvt    integer(n) */
-/*                the pivot VC_GEE_vector from dgeco or dgefa. */
-
-/*        work    double precision(n) */
-/*                work VC_GEE_vector.  contents destroyed. */
-
-/*        job     integer */
-/*                = 11   both determinant and inverse. */
-/*                = 01   inverse only. */
-/*                = 10   determinant only. */
-
-/*     on return */
-
-/*        a       inverse of original matrix if requested. */
-/*                otherwise unchanged. */
-
-/*        det     double precision(2) */
-/*                determinant of original matrix if requested. */
-/*                otherwise not referenced. */
-/*                determinant = det(1) * 10.0**det(2) */
-/*                with  1.0 .le. dabs(det(1)) .lt. 10.0 */
-/*                or  det(1) .eq. 0.0 . */
-
-/*     error condition */
-
-/*        a division by zero will occur if the input factor contains */
-/*        a zero on the diagonal and the inverse is requested. */
-/*        it will not occur if the subroutines are called correctly */
-/*        and if dgeco has set rcond .gt. 0.0 or dgefa has set */
-/*        info .eq. 0 . */
-
-/*     linpack. this version dated 08/14/78 . */
-/*     cleve moler, university of new mexico, argonne national lab. */
-
-/*     subroutines and functions */
-
-/*     blas daxpy,dscal,dswap */
-/*     fortran dabs,mod */
-
-/*     internal variables */
-
-
-
-/*     compute determinant */
-
-    /* Parameter adjustments */
-    --work;
-    --det;
-    --ipvt;
-    a_dim1 = *lda;
-    a_offset = a_dim1 + 1;
-    a -= a_offset;
-
-    /* Function Body */
-    if (*job / 10 == 0) {
-	goto L70;
-    }
-    det[1] = 1.;
-    det[2] = 0.;
-    ten = 10.;
-    i__1 = *n;
-    for (i = 1; i <= i__1; ++i) {
-	if (ipvt[i] != i) {
-	    det[1] = -det[1];
-	}
-	det[1] = a[i + i * a_dim1] * det[1];
-/*        ...exit */
-	if (det[1] == 0.) {
-	    goto L60;
-	}
-L10:
-	if (abs(det[1]) >= 1.) {
-	    goto L20;
-	}
-	det[1] = ten * det[1];
-	det[2] += -1.;
-	goto L10;
-L20:
-L30:
-	if (abs(det[1]) < ten) {
-	    goto L40;
-	}
-	det[1] /= ten;
-	det[2] += 1.;
-	goto L30;
-L40:
-/* L50: */
-	;
-    }
-L60:
-L70:
-
-/*     compute inverse(u) */
-
-    if (*job % 10 == 0) {
-	goto L150;
-    }
-    i__1 = *n;
-    for (k = 1; k <= i__1; ++k) {
-	a[k + k * a_dim1] = 1. / a[k + k * a_dim1];
-	t = -a[k + k * a_dim1];
-	i__2 = k - 1;
-	VC_GEE_dscalXXY_(&i__2, &t, &a[k * a_dim1 + 1], &c__1);
-	kp1 = k + 1;
-	if (*n < kp1) {
-	    goto L90;
-	}
-	i__2 = *n;
-	for (j = kp1; j <= i__2; ++j) {
-	    t = a[k + j * a_dim1];
-	    a[k + j * a_dim1] = 0.;
-	    VC_GEE_daxpyXXY_(&k, &t, &a[k * a_dim1 + 1], &c__1, &a[j * a_dim1 + 1], &
-		    c__1);
-/* L80: */
-	}
-L90:
-/* L100: */
-	;
-    }
-
-/*        form inverse(u)*inverse(l) */
-
-    nm1 = *n - 1;
-    if (nm1 < 1) {
-	goto L140;
-    }
-    i__1 = nm1;
-    for (kb = 1; kb <= i__1; ++kb) {
-	k = *n - kb;
-	kp1 = k + 1;
-	i__2 = *n;
-	for (i = kp1; i <= i__2; ++i) {
-	    work[i] = a[i + k * a_dim1];
-	    a[i + k * a_dim1] = 0.;
-/* L110: */
-	}
-	i__2 = *n;
-	for (j = kp1; j <= i__2; ++j) {
-	    t = work[j];
-	    VC_GEE_daxpyXXY_(n, &t, &a[j * a_dim1 + 1], &c__1, &a[k * a_dim1 + 1], &
-		    c__1);
-/* L120: */
-	}
-	l = ipvt[k];
-	if (l != k) {
-	    VC_GEE_dswapXXY_(n, &a[k * a_dim1 + 1], &c__1, &a[l * a_dim1 + 1], &c__1);
-	}
-/* L130: */
-    }
-L140:
-L150:
-    return 0;
-} /* dgedi_ */
-
-/* dgefa.f -- translated by f2c (version of 21 October 1993  13:46:10).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
-*/
-
-
-/* Table of constant values */
-
-
-static /* Subroutine */ int VC_GEE_dgefaXXY_(a, lda, n, ipvt, info)
-doublereal *a;
-integer *lda, *n, *ipvt, *info;
-{
-    /* System generated locals */
-    integer a_dim1, a_offset, i__1, i__2, i__3;
-
-    /* Local variables */
-    static integer j, k, l;
-    static doublereal t;
-    static /* Subroutine */ int VC_GEE_dscalXXY_(), VC_GEE_daxpyXXY_();
-    static integer VC_GEE_idamaxXXY_();
-    static integer kp1, nm1;
-
-/*     dgefa factors a double precision matrix by gaussian elimination. */
-
-/*     dgefa is usually called by dgeco, but it can be called */
-/*     directly with a saving in time if  rcond  is not needed. */
-/*     (time for dgeco) = (1 + 9/n)*(time for dgefa) . */
-
-/*     on entry */
-
-/*        a       double precision(lda, n) */
-/*                the matrix to be factored. */
-
-/*        lda     integer */
-/*                the leading dimension of the array  a . */
-
-/*        n       integer */
-/*                the order of the matrix  a . */
-
-/*     on return */
-
-/*        a       an upper triangular matrix and the multipliers */
-/*                which were used to obtain it. */
-/*                the factorization can be written  a = l*u  where */
-/*                l  is a product of permutation and unit lower */
-/*                triangular matrices and  u  is upper triangular. */
-
-/*        ipvt    integer(n) */
-/*                an integer VC_GEE_vector of pivot indices. */
-
-/*        info    integer */
-/*                = 0  normal value. */
-/*                = k  if  u(k,k) .eq. 0.0 .  this is not an error */
-/*                     condition for this subroutine, but it does */
-/*                     indicate that dgesl or dgedi will divide by zero */
-/*                     if called.  use  rcond  in dgeco for a reliable */
-/*                     indication of singularity. */
-
-/*     linpack. this version dated 08/14/78 . */
-/*     cleve moler, university of new mexico, argonne national lab. */
-
-/*     subroutines and functions */
-
-/*     blas daxpy,dscal,idamax */
-
-/*     internal variables */
-
-
-
-/*     gaussian elimination with partial pivoting */
-
-    /* Parameter adjustments */
-    --ipvt;
-    a_dim1 = *lda;
-    a_offset = a_dim1 + 1;
-    a -= a_offset;
-
-    /* Function Body */
-    *info = 0;
-    nm1 = *n - 1;
-    if (nm1 < 1) {
-	goto L70;
-    }
-    i__1 = nm1;
-    for (k = 1; k <= i__1; ++k) {
-	kp1 = k + 1;
-
-/*        find l = pivot index */
-
-	i__2 = *n - k + 1;
-	l = VC_GEE_idamaxXXY_(&i__2, &a[k + k * a_dim1], &c__1) + k - 1;
-	ipvt[k] = l;
-
-/*        zero pivot implies this column already triangularized */
-
-	if (a[l + k * a_dim1] == 0.) {
-	    goto L40;
-	}
-
-/*           interchange if necessary */
-
-	if (l == k) {
-	    goto L10;
-	}
-	t = a[l + k * a_dim1];
-	a[l + k * a_dim1] = a[k + k * a_dim1];
-	a[k + k * a_dim1] = t;
-L10:
-
-/*           compute multipliers */
-
-	t = -1. / a[k + k * a_dim1];
-	i__2 = *n - k;
-	VC_GEE_dscalXXY_(&i__2, &t, &a[k + 1 + k * a_dim1], &c__1);
-
-/*           row elimination with column indexing */
-
-	i__2 = *n;
-	for (j = kp1; j <= i__2; ++j) {
-	    t = a[l + j * a_dim1];
-	    if (l == k) {
-		goto L20;
-	    }
-	    a[l + j * a_dim1] = a[k + j * a_dim1];
-	    a[k + j * a_dim1] = t;
-L20:
-	    i__3 = *n - k;
-	    VC_GEE_daxpyXXY_(&i__3, &t, &a[k + 1 + k * a_dim1], &c__1, &a[k + 1 + j * 
-		    a_dim1], &c__1);
-/* L30: */
-	}
-	goto L50;
-L40:
-	*info = k;
-L50:
-/* L60: */
-	;
-    }
-L70:
-    ipvt[*n] = *n;
-    if (a[*n + *n * a_dim1] == 0.) {
-	*info = *n;
-    }
-    return 0;
-} /* dgefa_ */
-
-/* dgidamax.f -- translated by f2c (version of 21 October 1993  13:46:10).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
-*/
-
-
-static integer VC_GEE_idamaxXXY_(n, dx, incx)
-integer *n;
-doublereal *dx;
-integer *incx;
-{
-    /* System generated locals */
-    integer ret_val, i__1;
-    doublereal d__1;
-
-    /* Local variables */
-    static doublereal dmax_;
-    static integer i, ix;
-
-
-/*     finds the index of element having max. absolute value. */
-/*     jack dongarra, linpack, 3/11/78. */
-
-
-    /* Parameter adjustments */
-    --dx;
-
-    /* Function Body */
-    ret_val = 0;
-    if (*n < 1) {
-	return ret_val;
-    }
-    ret_val = 1;
-    if (*n == 1) {
-	return ret_val;
-    }
-    if (*incx == 1) {
-	goto L20;
-    }
-
-/*        code for increment not equal to 1 */
-
-    ix = 1;
-    dmax_ = abs(dx[1]);
-    ix += *incx;
-    i__1 = *n;
-    for (i = 2; i <= i__1; ++i) {
-	if ((d__1 = dx[ix], abs(d__1)) <= dmax_) {
-	    goto L5;
-	}
-	ret_val = i;
-	dmax_ = (d__1 = dx[ix], abs(d__1));
-L5:
-	ix += *incx;
-/* L10: */
-    }
-    return ret_val;
-
-/*        code for increment equal to 1 */
-
-L20:
-    dmax_ = abs(dx[1]);
-    i__1 = *n;
-    for (i = 2; i <= i__1; ++i) {
-	if ((d__1 = dx[i], abs(d__1)) <= dmax_) {
-	    goto L30;
-	}
-	ret_val = i;
-	dmax_ = (d__1 = dx[i], abs(d__1));
-L30:
-	;
-    }
-    return ret_val;
-} /* idamax_ */
-
-/* dscal.f -- translated by f2c (version of 21 October 1993  13:46:10).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
-*/
-
-
-static /* Subroutine */ int VC_GEE_dscalXXY_(n, da, dx, incx)
-integer *n;
-doublereal *da, *dx;
-integer *incx;
-{
-    /* System generated locals */
-    integer i__1, i__2;
-
-    /* Local variables */
-    static integer i, m, nincx, mp1;
-
-
-/*     scales a VC_GEE_vector by a constant. */
-/*     uses unrolled loops for increment equal to one. */
-/*     jack dongarra, linpack, 3/11/78. */
-
-
-    /* Parameter adjustments */
-    --dx;
-
-    /* Function Body */
-    if (*n <= 0) {
-	return 0;
-    }
-    if (*incx == 1) {
-	goto L20;
-    }
-
-/*        code for increment not equal to 1 */
-
-    nincx = *n * *incx;
-    i__1 = nincx;
-    i__2 = *incx;
-    for (i = 1; i__2 < 0 ? i >= i__1 : i <= i__1; i += i__2) {
-	dx[i] = *da * dx[i];
-/* L10: */
-    }
-    return 0;
-
-/*        code for increment equal to 1 */
-
-
-/*        clean-up loop */
-
-L20:
-    m = *n % 5;
-    if (m == 0) {
-	goto L40;
-    }
-    i__2 = m;
-    for (i = 1; i <= i__2; ++i) {
-	dx[i] = *da * dx[i];
-/* L30: */
-    }
-    if (*n < 5) {
-	return 0;
-    }
-L40:
-    mp1 = m + 1;
-    i__2 = *n;
-    for (i = mp1; i <= i__2; i += 5) {
-	dx[i] = *da * dx[i];
-	dx[i + 1] = *da * dx[i + 1];
-	dx[i + 2] = *da * dx[i + 2];
-	dx[i + 3] = *da * dx[i + 3];
-	dx[i + 4] = *da * dx[i + 4];
-/* L50: */
-    }
-    return 0;
-} /* dscal_ */
-
-/* dswap.f -- translated by f2c (version of 21 October 1993  13:46:10).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
-*/
-
-
-static /* Subroutine */ int VC_GEE_dswapXXY_(n, dx, incx, dy, incy)
-integer *n;
-doublereal *dx;
-integer *incx;
-doublereal *dy;
-integer *incy;
-{
-    /* System generated locals */
-    integer i__1;
-
-    /* Local variables */
-    static integer i, m;
-    static doublereal dtemp;
-    static integer ix, iy, mp1;
-
-
-/*     interchanges two VC_GEE_vectors. */
-/*     uses unrolled loops for increments equal one. */
-/*     jack dongarra, linpack, 3/11/78. */
-
-
-    /* Parameter adjustments */
-    --dy;
-    --dx;
-
-    /* Function Body */
-    if (*n <= 0) {
-	return 0;
-    }
-    if (*incx == 1 && *incy == 1) {
-	goto L20;
-    }
-
-/*       code for unequal increments or equal increments not equal */
-/*         to 1 */
-
-    ix = 1;
-    iy = 1;
-    if (*incx < 0) {
-	ix = (-(*n) + 1) * *incx + 1;
-    }
-    if (*incy < 0) {
-	iy = (-(*n) + 1) * *incy + 1;
-    }
-    i__1 = *n;
-    for (i = 1; i <= i__1; ++i) {
-	dtemp = dx[ix];
-	dx[ix] = dy[iy];
-	dy[iy] = dtemp;
-	ix += *incx;
-	iy += *incy;
-/* L10: */
-    }
-    return 0;
-
-/*       code for both increments equal to 1 */
-
-
-/*       clean-up loop */
-
-L20:
-    m = *n % 3;
-    if (m == 0) {
-	goto L40;
-    }
-    i__1 = m;
-    for (i = 1; i <= i__1; ++i) {
-	dtemp = dx[i];
-	dx[i] = dy[i];
-	dy[i] = dtemp;
-/* L30: */
-    }
-    if (*n < 3) {
-	return 0;
-    }
-L40:
-    mp1 = m + 1;
-    i__1 = *n;
-    for (i = mp1; i <= i__1; i += 3) {
-	dtemp = dx[i];
-	dx[i] = dy[i];
-	dy[i] = dtemp;
-	dtemp = dx[i + 1];
-	dx[i + 1] = dy[i + 1];
-	dy[i + 1] = dtemp;
-	dtemp = dx[i + 2];
-	dx[i + 2] = dy[i + 2];
-	dy[i + 2] = dtemp;
-/* L50: */
-    }
-    return 0;
-} /* dswap_ */
 
 /* gee support @(#) VC_GEE_diag_as_vec.c 3.3 94/03/09 */
 
@@ -2415,15 +1718,9 @@ MATRIX *x;
 /* dependence on Numerical Recipes code removed by Thomas Lumley */
 /* normal pdf/cdf now taken from internal R routines (more accurate, too) */
 
-#if defined(R_VERSION) && R_VERSION >= R_Version(0,99,0)
-#include <R_ext/Mathlib.h>
-#define dnorm1(x) dnorm4(x, 0.0, 1.0, 0)
-#define pnorm1(x) pnorm5(x, 0.0, 1.0, 1, 0)
-#else
-#include <Mathlib.h>
-#define dnorm1(x) dnorm(x, 0.0, 1.0)
-#define pnorm1(x) pnorm(x, 0.0, 1.0)
-#endif
+#include <Rmath.h>
+#define dnorm1(x) dnorm(x, 0.0, 1.0, 0)
+#define pnorm1(x) pnorm(x, 0.0, 1.0, 1, 0)
 
 
 /* following added by pj catalano to support probit link option in cgee.c */
